import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import scipy.stats as st
import statsmodels.formula.api as smf

monData = pd.read_csv("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Data/Warming_Monarchs.csv")
# Exclude lost or missed observations
monData2 = monData.dropna(subset=['dead'])
monData2 = monData[monData['instar']==3]

## TIME TO PUPATION ###
# exclude dead ones
timeData = monData2[monData2['dead']==0]

# average by treatment
timeSummary = timeData.groupby(['Treatment'])['time'].agg({'mean': np.mean, 'SE': lambda x: x.std()/np.sqrt(x.count())})
# plot time to pupation
f, ax = plt.subplots()
ax.errorbar([1, 2], timeSummary['mean'], yerr=timeSummary['SE'], fmt='o', capsize=0, ms=8, ecolor='k', mfc='k')
ax.set_ylim([10, 12])
ax.set_xlim([0.5, 2.5])
ax.set_xticks([1, 2])
ax.set_xticklabels(['Ambient', 'Warmed'])
ax.set_ylabel("Days to Pupation")
ax.set_xlabel("Warming Treatment")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/pupationTime.pdf",bbox_inches = 'tight')
plt.show()

timeMod = smf.ols(formula='time ~ TempQuant', data=timeData)
timeFit = timeMod.fit()
print timeFit.summary()

plt.plot(timeFit.predict(), timeFit.resid, 'ko')
plt.axhline(0, linestyle='dashed')
plt.xlabel('Fitted')
plt.ylabel('Residuals')
plt.show()

st.probplot(timeFit.resid, dist='norm', plot=plt)
plt.show()



tPred = np.linspace(timeData['TempQuant'].min(), timeData['TempQuant'].max(), 100)
tPred2 = np.column_stack((np.ones(100), tPred))
ses = np.sqrt(np.diag( tPred2.dot(timeFit.cov_params()).dot(tPred2.T) ))
tcrit = st.t.ppf(0.975, 25)

yhat = timeFit.predict(exog=dict(TempQuant=tPred))

f, ax = plt.subplots()
ax.fill_between(tPred, yhat-tcrit*ses, yhat+tcrit*ses, facecolor='lightgrey', edgecolor='None')
ax.plot(timeData[timeData['Treatment']=='Ctrl']['TempQuant'], timeData[timeData['Treatment']=='Ctrl']['time'], 'wo', ms=10, mew=1, label='Ambient')
ax.plot(timeData[timeData['Treatment']=='Heat']['TempQuant'], timeData[timeData['Treatment']=='Heat']['time'], 'ko', ms=10, mew=1, label='Warmed')
ax.plot(tPred, yhat, 'k-', lw=2)
#ax.set_ylim([ , ])
#ax.set_xlim([ , ])
ax.set_ylabel("Time to Pupation (Days)")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
#ax.spines['left'].set_bounds()
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
ax.legend(loc='best')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/pupationTime_Quant.pdf",bbox_inches = 'tight')
plt.show()


## PUPAL MASS ##
# exclude dead ones
pupData = monData2[monData2['dead']==0]
pupData.rename(columns={'mass.final':'chrys_mass'}, inplace=True)

# average by treatment
pupSummary = pupData.groupby(['Treatment'])['chrys_mass'].agg({'mean' : np.mean, 'SE': lambda x: x.std()/np.sqrt(x.count())})
# plot pupal mass
f, ax = plt.subplots()
ax.errorbar([1, 2], pupSummary['mean'], yerr=pupSummary['SE'], fmt='o', capsize=0, ms=8, ecolor='k', mfc='k')
ax.set_ylim([1, 1.5])
ax.set_xlim([0.5, 2.5])
ax.set_xticks([1, 2])
ax.set_xticklabels(['Ambient', 'Warmed'])
ax.set_ylabel("Pupal Mass (g)")
ax.set_xlabel("Warming Treatment")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/pupalMass.pdf",bbox_inches = 'tight')
plt.show()

pupMod = smf.ols(formula='chrys_mass ~ TempQuant', data=pupData)
pupFit = pupMod.fit()
print pupFit.summary()

f, ax = plt.subplots()
ax.plot(pupData[pupData['Treatment']=='Ctrl']['TempQuant'], pupData[pupData['Treatment']=='Ctrl']['chrys_mass'], 'wo', ms=10, mew=1, label='Ambient')
ax.plot(pupData[pupData['Treatment']=='Heat']['TempQuant'], pupData[pupData['Treatment']=='Heat']['chrys_mass'], 'ko', ms=10, mew=1, label='Warmed')
#ax.set_ylim([ , ])
#ax.set_xlim([ , ])
ax.set_ylabel("Pupal Mass (g)")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
#ax.spines['left'].set_bounds()
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
ax.legend(loc='best')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/pupalMass_Quant.pdf",bbox_inches = 'tight')
plt.show()



## PROBABILITY OF MORTALITY
deadData = monData2.dropna(subset=['dead'])

print len(deadData[deadData['Treatment']=='Ctrl'])
print len(deadData[deadData['Treatment']=='Heat'])

jitterA = st.norm.rvs(0, 0.02, len(deadData[deadData['Treatment']=='Ctrl']))
jitterW = st.norm.rvs(0, 0.02, len(deadData[deadData['Treatment']=='Heat']))


f, ax = plt.subplots()
ax.plot(deadData[deadData['Treatment']=='Ctrl']['TempQuant'], deadData[deadData['Treatment']=='Ctrl']['dead'] + jitterA, 'wo', mew=1, label='Ambient')
ax.plot(deadData[deadData['Treatment']=='Heat']['TempQuant'], deadData[deadData['Treatment']=='Heat']['dead'] + jitterW, 'ko', mew=1, label='Warmed')
ax.set_ylim([ -0.1, 1.1])
#ax.set_xlim([ , ])
ax.set_ylabel("Probability of Mortality")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
ax.spines['left'].set_bounds(0, 1)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
ax.legend(loc='best')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/mortality_Quant.pdf",bbox_inches = 'tight')
plt.show()

mortMod = smf.logit(formula='dead ~ TempQuant', data=deadData)
mortFit = mortMod.fit()
print mortFit.summary()

mMod2 = smf.logit(formula='dead ~ C(Treatment)', data=deadData)
print mMod2.fit().summary()