import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import scipy.stats as st
import statsmodels.formula.api as smf

traitData = pd.read_csv('/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Data/Tuberosa_traits.csv')

# SLA
slaData = traitData[['plot', 'treatment', 'tempQuant', 'dry.mass', 'area']]
slaData.dropna(inplace=True)
slaData['SLA'] = slaData['area'] / slaData['dry.mass']

# plot
f, ax = plt.subplots()
ax.plot(slaData[slaData['treatment']=='Ambient']['tempQuant'], slaData[slaData['treatment']=='Ambient']['SLA'], 'wo', ms=10, mew=1, label='Ambient')
ax.plot(slaData[slaData['treatment']=='Heat']['tempQuant'], slaData[slaData['treatment']=='Heat']['SLA'], 'ko', ms=10, mew=1, label='Ambient')
ax.set_ylim([100, 500])
#ax.set_xlim([ , ])
ax.set_ylabel("SLA")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
ax.spines['left'].set_bounds(100, 500)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/sla_Quant.pdf",bbox_inches = 'tight')
plt.show()

slaMod = smf.ols('SLA ~ tempQuant', data=slaData).fit()
print slaMod.summary()


# Pct H20
waterData = traitData[['plot', 'treatment', 'tempQuant', 'dry.mass', 'wet.mass']]
waterData.dropna(inplace=True)
waterData['PctH20'] = (1-waterData['dry.mass']/waterData['wet.mass'])*100

# plot
f, ax = plt.subplots()
ax.plot(waterData[waterData['treatment']=='Ambient']['tempQuant'], waterData[waterData['treatment']=='Ambient']['PctH20'], 'wo', ms=10, mew=1, label='Ambient')
ax.plot(waterData[waterData['treatment']=='Heat']['tempQuant'], waterData[waterData['treatment']=='Heat']['PctH20'], 'ko', ms=10, mew=1, label='Ambient')
ax.set_ylim([60, 90])
#ax.set_xlim([ , ])
ax.set_ylabel("Water Content (%H20)")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
ax.spines['left'].set_bounds(60, 90)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/water_Quant.pdf",bbox_inches = 'tight')
plt.show()

waterMod = smf.ols('PctH20 ~ tempQuant', data=waterData).fit()
print waterMod.summary()


# Latex Conc
latexData = traitData[['plot', 'treatment', 'tempQuant', 'dry.mass', 'Latex_mg']]
latexData.dropna(inplace=True)
latexData['lat_Conc'] = latexData['Latex_mg']/latexData['dry.mass']
latexData = latexData[latexData['lat_Conc'] >= 0]

# plot
f, ax = plt.subplots()
ax.plot(latexData[latexData['treatment']=='Ambient']['tempQuant'], latexData[latexData['treatment']=='Ambient']['lat_Conc'], 'wo', ms=10, mew=1, label='Ambient')
ax.plot(latexData[latexData['treatment']=='Heat']['tempQuant'], latexData[latexData['treatment']=='Heat']['lat_Conc'], 'ko', ms=10, mew=1, label='Ambient')
ax.set_ylim([-1, 30])
ax.set_yticks(np.linspace(0, 30, 7))
#ax.set_xlim([ , ])
ax.set_ylabel("Latex Concentration (mg / g)")
ax.set_xlabel(u"Temperature (\u00B0C)")
ax.spines['top'].set_visible(False)
ax.spines['right'].set_visible(False)
ax.spines['bottom'].set_position(('outward', 10))
#ax.spines['bottom'].set_bounds()
ax.spines['left'].set_position(('outward', 10))
ax.spines['left'].set_bounds(0, 30)
ax.yaxis.set_ticks_position('left')
ax.xaxis.set_ticks_position('bottom')
plt.savefig("/Users/Nate/Documents/FIU/Research/Warming_Monarchs/Analyses/latex_Quant.pdf",bbox_inches = 'tight')
plt.show()

latexMod = smf.ols('lat_Conc ~ tempQuant', data=latexData).fit()
print latexMod.summary()0